@@ -6,14 +6,14 @@ use warnings;
 	package Ask;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.010';
+	our $VERSION   = '0.011';
 	
 	use Carp qw(croak);
 	use Moo::Role qw();
 	use Module::Runtime qw(use_module use_package_optimistically);
 	use Module::Pluggable (
 		search_path => 'Ask',
-		except      => [qw/ Ask::API Ask::Functions /],
+		except      => [qw/ Ask::API Ask::Functions Ask::Question /],
 		inner       => 0,
 		require     => 0,
 		sub_name    => '__plugins',
@@ -25,7 +25,7 @@ use warnings;
 		if (@_) {
 			require Ask::Functions;
 			unshift @_, 'Ask::Functions';
-			goto \&Ask::Functions::import;
+			goto( $_[0]->can( 'import' ) );
 		}
 	}
 	
@@ -58,6 +58,11 @@ use warnings;
 		
 		croak "No usable backend for Ask";
 	}
+	
+	sub Q {
+		require Ask::Question;
+		'Ask::Question'->new( @_ );
+	}
 }
 
 1;
